
From: NeilBrown <neilb@cse.unsw.edu.au>

Adopt standard kernel style by defining a no-op function instead of putting
ifdef's in the code where the function is called.

Signed-off-by: J. Bruce Fields <bfields@citi.umich.edu>
Signed-off-by: Neil Brown <neilb@cse.unsw.edu.au>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 fs/nfsd/nfsctl.c           |    4 ----
 include/linux/nfsd_idmap.h |    5 +++++
 2 files changed, 5 insertions(+), 4 deletions(-)

diff -puN fs/nfsd/nfsctl.c~nfsd4-idmap-initialization fs/nfsd/nfsctl.c
--- 25/fs/nfsd/nfsctl.c~nfsd4-idmap-initialization	Thu Jun  2 16:25:07 2005
+++ 25-akpm/fs/nfsd/nfsctl.c	Thu Jun  2 16:25:07 2005
@@ -398,9 +398,7 @@ static int __init init_nfsd(void)
 	nfsd_export_init();	/* Exports table */
 	nfsd_lockd_init();	/* lockd->nfsd callbacks */
 	nfs4_state_init();	/* NFSv4 locking state */
-#ifdef CONFIG_NFSD_V4
 	nfsd_idmap_init();      /* Name to ID mapping */
-#endif /* CONFIG_NFSD_V4 */
 	if (proc_mkdir("fs/nfs", NULL)) {
 		struct proc_dir_entry *entry;
 		entry = create_proc_entry("fs/nfs/exports", 0, NULL);
@@ -427,9 +425,7 @@ static void __exit exit_nfsd(void)
 	remove_proc_entry("fs/nfs", NULL);
 	nfsd_stat_shutdown();
 	nfsd_lockd_shutdown();
-#ifdef CONFIG_NFSD_V4
 	nfsd_idmap_shutdown();
-#endif /* CONFIG_NFSD_V4 */
 	unregister_filesystem(&nfsd_fs_type);
 }
 
diff -puN include/linux/nfsd_idmap.h~nfsd4-idmap-initialization include/linux/nfsd_idmap.h
--- 25/include/linux/nfsd_idmap.h~nfsd4-idmap-initialization	Thu Jun  2 16:25:07 2005
+++ 25-akpm/include/linux/nfsd_idmap.h	Thu Jun  2 16:25:07 2005
@@ -43,8 +43,13 @@
 /* XXX from linux/nfs_idmap.h */
 #define IDMAP_NAMESZ 128
 
+#ifdef CONFIG_NFSD_V4
 void nfsd_idmap_init(void);
 void nfsd_idmap_shutdown(void);
+#else
+static inline void nfsd_idmap_init(void) {};
+static inline void nfsd_idmap_shutdown(void) {};
+#endif
 
 int nfsd_map_name_to_uid(struct svc_rqst *, const char *, size_t, __u32 *);
 int nfsd_map_name_to_gid(struct svc_rqst *, const char *, size_t, __u32 *);
_
